@@ -34,7 +34,13 @@ class NodeOption(discord.SelectOption):
             label=shorten_string(max_length=100, string=f"{index + 1}. {data['name']}"),
             description=shorten_string(
                 max_length=100,
-                string=_("ID: {} || SSL: {} || Search-only: {}").format(node.id, data["ssl"], data["search_only"]),
+                string=_(
+                    "Identifier: {node_identifier_variable_do_not_translate} || SSL: {node_ssl_variable_do_not_translate} || Search-only: {node_config_variable_do_not_translate}"
+                ).format(
+                    node_identifier_variable_do_not_translate=node.id,
+                    node_ssl_variable_do_not_translate=data["ssl"],
+                    node_config_variable_do_not_translate=data["search_only"],
+                ),
             ),
             value=f"{node.id}",
         )
